<?php
// Initialize the session
session_start();

// Check if the user is logged in, if not then redirect him to login page
if (!isset($_SESSION["loggedin"]) || $_SESSION["loggedin"] !== true) {
    header("location: ../../login");
    exit;
}

require_once "../../config.php";

if ($_SERVER["REQUEST_METHOD"] == "POST") {
    $title = trim($_POST["title"]);
    $content = trim($_POST["content"]);
    $author = trim($_POST["author"]);
    $videoID = trim($_POST["videoID"]);
    $date = trim($_POST["date"]);
    $category = trim($_POST["category"]);

    // Validate fields
    if (empty($title) || empty($content) || empty($author) || empty($date)) {
        $empty_err = "Todos campos com <b>*</b> precisam ser preenchidos";
    }

    // Check input errors before inserting in database
    if (empty($empty_err)) {

        // Prepare an insert statement
        $sql = "INSERT INTO posts (title, content, author, videoID, date, category) VALUES (?, ?, ?, ?, ?, ?)";

        if ($stmt = $mysqli->prepare($sql)) {
            // Bind variables to the prepared statement as parameters
            $stmt->bind_param("ssssss", $param_title, $param_content, $param_author, $param_videoID, $param_date, $param_category);

            // Set parameters
            $param_title = $title;
            $param_content = $content;
            $param_author = $author;
            $param_videoID = (empty($videoID)) ? NULL : $videoID;
            $param_date = $date;
            $param_category = $category;

            // Attempt to execute the prepared statement
            if ($stmt->execute()) {
                // Redirect to login page
                header("location: ../../control-panel");
            } else {
                echo "Something went wrong. Please try again later.";
            }

            // Close statement
            $stmt->close();
        }
    }

    // Close connection
    $mysqli->close();
}

$pageTitle = "Novo Post";
$styleSheetPath = "/post/new/style.css";

?>
<?php include $_SERVER['DOCUMENT_ROOT'] . '/templates/header/header.php'; ?>
<div class="container">
    <div class="wrapper">
        <h2>New Post</h2>
        <form action="<?php echo htmlspecialchars($_SERVER["PHP_SELF"]); ?>" method="post">
            <span class="help-block"><?php echo $empty_err; ?></span>
            <div class="form-group">
                <label>Título *</label>
                <input type="text" name="title" class="form-control">
            </div>
            <div class="form-group">
                <label>Conteudo/Descrição *</label>
                <textarea type="text" name="content" class="form-control content"> </textarea>

            </div>
            <div class=" form-group">
                <label>Autor *</label>
                <input type="text" name="author" class="form-control">

            </div>
            <div class="form-group">
                <label>ID do Vídeo</label>
                <input type="text" name="videoID" class="form-control">

            </div>
            <div class="form-group">
                <label for="category">Selecione uma Categoria</label>
                <br>
                <select class="select-box" name="category">
                    <option value="ARTES VISUAIS">Artes Visuais</option>
                    <option value="ARTES CÊNICAS">Artes Cênicas</option>
                    <option value="LITERATURA">Literatura</option>
                    <option value="DANÇA">Dança</option>
                    <option value="MÚSICA">Música</option>
                    <option value="DANÇA">Dança</option>
                    <option value="CULTURA POPULAR">Cultura Popular</option>
                    <option value="PROJETOS ARTÍSTICO-CULTURAIS">Projetos Artístico-Culturais</option>
                    <option value="IDEIAS CULTURAIS">Ideias Culturais</option>
                </select>
            </div>
            <div class="form-group">
                <label>Data * <i>Ex: 31/02/2021</i></label>
                <br>
                <input type="date" required pattern="[0-9]{2}-[0-9]{2}/[0-9]{4}" name="date" class="form-control">

            </div>
            <!-- required pattern="[0-9]{4}-[0-9]{2}-[0-9]{2}" -->
            <div class="form-group">
                <input type="submit" class="btn btn-primary" value="Submit">
                <input type="reset" class="btn btn-default" value="Reset">
            </div>

        </form>
    </div>
</div>
<?php include $_SERVER['DOCUMENT_ROOT'] . '/templates/footer/footer.php'; ?>